--Returns true if player is currently in trade chat, false if not
local function IsInTrade()
  local numChannels = GetNumDisplayChannels();
  local tradeConfirmed = false;
    
  --iterating through all current chat channels
  for i = 1, numChannels, 1 do
    local name, _,_,_,_, active= GetChannelDisplayInfo(i);
    if (name=="Trade" and active) then
      return true;
    end
  end
  return false;
end

--Returns true if player is in the global chat channel, false if not
local function IsInGlobal()
    
  local numChannels = GetNumDisplayChannels();
  local tradeConfirmed = false;
    
  --interating through all current chat channels
  for i = 1, numChannels, 1 do
    local name, _,_,_,_, active= GetChannelDisplayInfo(i);
    if (string.lower(name)=="evertrade") then
      return true;
    end
  end
  return false;
end

--Called once at loading
--Sets variables to their initial values, or saved variables to their default values if not already saved
local function SetGlobalVariables()
  
  --All non-saved global variables will be stored in this table
  ET_VARS = {};
  --The version of the communication protocol, not of the addon itself
  ET_VARS["version"] = "v2";
  --Long messages that must be split into two parts to be relayed all have a messageID attached to them
  --for filing on the receiving client, cycles from 1-9 and then back to 1
  ET_VARS["messageID"] = 1;
  --Table used to store, temporarily, all long messages that are split into two parts
  ET_VARS["inbox"] = {};
  --Short list of messages recently displayed by addon, prevents spamming of same text
  ET_VARS["cache"] = {0,0,0,0,0};
  --Boolean representing whether the player is in a guild or not
  ET_VARS["inGuild"] = IsInGuild();
  --Boolean representing whether the player is in trade chat or not
  ET_VARS["inTrade"] = IsInTrade();
  
  --All saved variables are stored in this table.
  if (ET_SAVED_VARS==nil) then
    ET_SAVED_VARS = {};
  end
  
  --Holds the formatting string
  if (ET_SAVED_VARS["formatting"]==nil) then
    ET_SAVED_VARS["formatting"] = "[2. Trade] [#a]: #m";
  end
  
  --Holds the color r,g,b values from 0-255
  if (ET_SAVED_VARS["colors"]==nil) then
    ET_SAVED_VARS["colors"] = {255, 192, 192};
  end
  
  --Boolean of whether or not player wishes to receive out-of-city trade messages
  if (ET_SAVED_VARS["show"]==nil) then
    ET_SAVED_VARS["show"] = true;
  end

  --Boolean of whether or not player wishes to send/receive messages globally
  if (ET_SAVED_VARS["inGlobal"]==nil) then
    ET_SAVED_VARS["inGlobal"] = true;
  end

  if (ET_SAVED_VARS["window"]==nil) then
    ET_SAVED_VARS["window"] = 1;
  end

end 

--Registers/Unregisters certain game events depending on conditions
--Arguments:   trade - boolean, whether player is in trade channel or not
--             global - boolean, whether player is in the global channel or not
--             override - boolean, if false, the function will only care about changes to 
--             a player's trade/global status (whether they left or joined)
--             if true, the function will run blind to to previous channel states 
local function DoRegistrationLogic(trade, global, override)

  if (trade) then 
    if (ET_VARS["inTrade"]==false or override) then
      ET_VARS["inTrade"] = true;  
      if (ET_VARS["inGuild"] or ET_SAVED_VARS["inGlobal"]) then 
        this:RegisterEvent("CHAT_MSG_CHANNEL");
      end
      this:UnregisterEvent("CHAT_MSG_ADDON");
    end 
  elseif (ET_VARS["inTrade"] or override) then
    ET_VARS["inTrade"] = false;
    if (ET_SAVED_VARS["show"]) then
      if (ET_VARS["inGuild"]) then
        this:RegisterEvent("CHAT_MSG_ADDON");
      end
      if (ET_SAVED_VARS["inGlobal"]) then
        this:RegisterEvent("CHAT_MSG_CHANNEL");
      else
        this:UnregisterEvent("CHAT_MSG_CHANNEL");
      end
    else
      this:UnregisterEvent("CHAT_MSG_ADDON");
      this:UnregisterEvent("CHAT_MSG_CHANNEL");
    end
  end
  if (global) then
    if (ET_SAVED_VARS["inGlobal"]==false or override) then
      ET_SAVED_VARS["inGlobal"] = true;
      if (ET_VARS["inTrade"]) then
        this:RegisterEvent("CHAT_MSG_CHANNEL");
      elseif (ET_SAVED_VARS["show"]) then
        this:RegisterEvent("CHAT_MSG_CHANNEL");
      else
        this:UnregisterEvent("CHAT_MSG_CHANNEL");
      end
    end
  elseif (ET_SAVED_VARS["inGlobal"] or override) then 
    ET_SAVED_VARS["inGlobal"] = false;
    if (ET_VARS["inTrade"]==false) then
      this:UnregisterEvent("CHAT_MSG_CHANNEL");
    end
  end
end

--All slash commands are sent to this function for processing
--arguments - string of all text sent by the user after the slash command
local function ProcessSlashCommand(arguments)
  
  --Taking whitespace off front and back of string
  local arguments = strtrim(arguments);

  --Format command with proper formatstring entered
  if (string.lower(string.sub(arguments,1,7))=="format ") then
      ET_SAVED_VARS["formatting"] = string.sub(arguments,8);       
      local formatText = string.gsub(ET_SAVED_VARS["formatting"],"#a","|cFFF3A325#a|cFFFFFFFF");
      formatText = string.gsub(formatText,"#m","|cFF25F3AD#m|cFFFFFFFF");
      DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] format:|cFFFFFFFF Formatting set to \""..formatText.."\"");
  
  --Format command without any formatstring given
  elseif (arguments=="format") then
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] format:|cFFFF0004 No Formatting Entered.");

  --Color command with some text behind it 
  elseif (string.lower(string.sub(arguments,1,6))=="color ") then
    
    --Checking input to determine its validity
     
    --Taken from wowwiki.com: args table will contain "color" in index 1, and 
    --user-entered colors in indexes 2-4
    local args = {};
    for s in string.gmatch(arguments, "[^ ]+") do
      tinsert(args, s);
    end

    args[2] = tonumber(args[2]);
    args[3] = tonumber(args[3]);
    args[4] = tonumber(args[4]);
    
    --User entered 3 actual numbers
    if (args[2]~=nil and args[3]~=nil and args[4]~=nil) then
    
      --Flooring numbers so they are all integers
      args[2]= floor(args[2]);
      args[3]= floor(args[3]);
      args[4]= floor(args[4]);

      --Correcting colors if they are out of 0-255 range
      if (args[2]>255) then
        args[2]= 255;
      end
      if (args[3]>255) then
        args[3]= 255;
      end
      if (args[4]>255) then
        args[4]= 255;
      end
      if (args[2]<0) then
        args[2]= 0;
      end
      if (args[3]<0) then
        args[3]= 0;
      end
      if (args[4]<0) then
        args[4]= 0;
      end
      
      --Verified proper RGB values
      ET_SAVED_VARS["colors"] = {args[2], args[3], args[4]};  
      local colorText = "|cFFFF0004"..ET_SAVED_VARS["colors"][1].." |cFF0BFC00"..ET_SAVED_VARS["colors"][2].." |cFF2357FF"..ET_SAVED_VARS["colors"][3];
      DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] colors:|cFFFFFFFF Color set to "..colorText);
    else 
      DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] colors:|cFFFF0004 Invalid Color Argument.");       
    end
  
  elseif (string.lower(string.sub(arguments,1,7))=="window ") then
    local window = strtrim(string.sub(arguments,8));
    
    local index;
    for i=1,NUM_CHAT_WINDOWS do
      if (string.lower(window)==string.lower(GetChatWindowInfo(i))) then
         index = i;
      end
    end
    
    if (index==nil) then
      DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] window:|cFFFF0004 That Window Does Not Exist.");
    else
      DEFAULT_CHAT_FRAME:AddMessage('|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] window:|cFFFFFFFF Display Window Set To "'..GetChatWindowInfo(index)..'"');
      ET_SAVED_VARS["window"] = index;
    end
  
  elseif (arguments=="window") then
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] colors:|cFFFF0004 No Window Name Entered.");

  --Color command with nothing else typed
  elseif (arguments=="color") then
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576] colors:|cFFFF0004 No Colors Entered.");

  --Show command
  elseif (string.lower(string.sub(arguments,1,4))=="show") then
    ET_SAVED_VARS["show"] = true;
    DoRegistrationLogic(ET_VARS["inTrade"], ET_SAVED_VARS["inGlobal"], true);
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF Trade Messages Will Be Shown.");
    
  --Hide command
  elseif (string.lower(string.sub(arguments,1,4))=="hide") then
    ET_SAVED_VARS["show"] = false;
    DoRegistrationLogic(ET_VARS["inTrade"], ET_SAVED_VARS["inGlobal"], true); 
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF Trade Messages Will Be Hidden.");

  --Reset command
  elseif (string.lower(string.sub(arguments,1,13))=="resetsettings") then
    ET_SAVED_VARS["colors"] = {255, 192, 192};
    ET_SAVED_VARS["show"] = true;
    ET_SAVED_VARS["formatting"] = "[2. Trade] [#a]: #m";
    
    if (ET_SAVED_VARS["inGlobal"]==false) then
      JoinChannelByName("EverTrade");
    end

    DoRegistrationLogic(ET_VARS["inTrade"], ET_SAVED_VARS["inGlobal"], true);
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF All Settings Have Been Reset.");
  
  --No arguments provided, prints out all command choices and their current values, if applicable
  elseif (arguments=="") then
    
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF Displays trade channel messages outside of cities.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576Slash Command: |cFFFFFFFF /et or /evertrade");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576Arguments:");
    
    local onOffText;
    if (ET_SAVED_VARS["show"]) then
      onOffText = "[|cFF0BFC00On|cFFF4F576]";
    else
      onOffText = "[|cFFFF0004Off|cFFF4F576]";
    end
    
    local colorText = "[|cFFFF0004"..ET_SAVED_VARS["colors"][1]..",|cFF0BFC00"..ET_SAVED_VARS["colors"][2]..",|cFF2357FF"..ET_SAVED_VARS["colors"][3].."|cFFF4F576]";
    
    local formatText = string.gsub(ET_SAVED_VARS["formatting"],"#a","|cFFF3A325#a|cFFFFFFFF");
    formatText = string.gsub(formatText,"#m","|cFF25F3AD#m|cFFFFFFFF");
    formatText = "[|cFFFFFFFF"..formatText.."|cFFF4F576]";

    local globalText;
    if (ET_SAVED_VARS["inGlobal"]) then
      globalText = "[|cFF0BFC00On|cFFF4F576]";
    else
      globalText = "[|cFFFF0004Off|cFFF4F576]";
    end

    local windowText = "[|cFFFFFFFF"..GetChatWindowInfo(ET_SAVED_VARS["window"]).."|cFFF4F576]";

    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576show:"..onOffText.."|cFFFFFFFF Shows trade channel messages.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576hide|cFFFFFFFF: Hides trade channel messages.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576color <r g b>:"..colorText.."|cFFFFFFFF Sets message color to red, green, and blue values (0-255).");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576format <formatstring>:"..formatText.."|cFFFFFFFF Sets the formatting of a trade message. #a is the variable for the author. #m is the variable for the message.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576global:"..globalText.."|cFFFFFFFF Toggles global sending and receiving. Requires the joining of a chat channel.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576window <window name>:"..windowText.."|cFFFFFFFF Sets the window name that relayed trade messages will display to.");
    DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF -|cFFF4F576resetsettings:|cFFFFFFFF Resets all settings to their default values.");

  
  --Global command entered
  elseif (string.lower(string.sub(arguments,1,6))=="global") then 
    
    if (ET_SAVED_VARS["inGlobal"]) then
      LeaveChannelByName("EverTrade");
      DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF Messages Will Not Be Sent Nor Received Globally.");
    else 
      local confirm = JoinChannelByName("EverTrade");
      if (confirm==nil) then
        DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFF0004 Could Not Join Global Message Channel.");
      else
        DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFFFFFF Messages Will Now Be Sent And Received Globally.");    
      end
    end
  else
    DEFAULT_CHAT_FRAME:AddMessage("|cFFF4F576[|cFF0BFC00EverTrade|cFFF4F576]:|cFFFF0004 Invalid Command.");
  end
end

--Hides all chat messages that originate from EverTrade global channel
local function filter(msg)
  if (string.lower(arg9)=="evertrade") then 
    return true; 
  end
end

--Sets filter function to channel message event
local function SuppressGlobalChat()
  ChatFrame_AddMessageEventFilter("CHAT_MSG_CHANNEL", filter);
end

--Called when addon has loaded
function EverTrade_Load()
    
  SetGlobalVariables();

  --Setting initial event registrations
  DoRegistrationLogic(ET_VARS["inTrade"], ET_SAVED_VARS["inGlobal"], true);

  --Registering slash commands
  SlashCmdList["ETCATCHALL"] = ProcessSlashCommand;
  SLASH_ETCATCHALL1 = "/et";
  SLASH_ETCATCHALL2 = "/evertrade";
  
  --Registering events
  this:RegisterEvent("PLAYER_GUILD_UPDATE");
  this:RegisterEvent("CHANNEL_FLAGS_UPDATED");
  this:RegisterEvent("CHAT_MSG_CHANNEL_NOTICE");
  
  --Hiding all message sent through global channel
  SuppressGlobalChat();
end

--Relays a message sent in trade 
--Arguments:    author - string, name of original message author
--              message - string, trade message sent
--              addon - boolean, true if message should be relayed through addon channel
--                               false if message should be relayed through global channel 
local function RelayTradeMessage(author, message, addon)  
  local authorLength = string.len(author);
  
  --Breaking item links if they are going to be sent over global channel 
  if (addon~=true) then
    message = string.gsub(message,"|","*&");
  end
  
  --If message if short enough to be sent in one part
  if (string.len(message)<=(247-authorLength)) then
    if (addon) then
      SendAddonMessage("ET" .. ET_VARS["version"] .. "1" .. authorLength, author .. message, "GUILD");
    else
      SendChatMessage("ET" .. ET_VARS["version"] .. "1" .. authorLength .. ";" .. author .. message, "CHANNEL", nil, GetChannelName("EverTrade"));
    end
  else --Message must be broken into two parts 
    if (addon) then
      SendAddonMessage("ET" .. ET_VARS["version"] .. "2" .. ET_VARS["messageID"] .. authorLength, "1"..author..string.sub(message,1,245-string.len(author)), "GUILD");
      SendAddonMessage("ET" .. ET_VARS["version"] .. "2" .. ET_VARS["messageID"], "2"..string.sub(message,246-string.len(author)), "GUILD");
    else 
      SendChatMessage("ET" .. ET_VARS["version"] .. "2" .. ET_VARS["messageID"] .. authorLength .. ";" .. "1"..author..string.sub(message,1,245-string.len(author)),  "CHANNEL", nil, GetChannelName("EverTrade"));
      SendChatMessage("ET" .. ET_VARS["version"] .. "2" .. ET_VARS["messageID"] .. ";" .. "2"..string.sub(message,246-string.len(author)),  "CHANNEL", nil, GetChannelName("EverTrade")); 
    end
    --Cycling messageID
    if (ET_VARS["messageID"]==9) then
      ET_VARS["messageID"] = 1;
    else 
      ET_VARS["messageID"] = ET_VARS["messageID"] + 1;
    end
  end  
end

--Displays the final message to the player
--Arguments:         text - string, text of message
--                  author - string, author of message 
local function DisplayMessage(text, author)
  
  --Substituting author and text into formatting string, creating player link out of author name
  local finalText = string.gsub(ET_SAVED_VARS["formatting"], "#a", "|Hplayer:"..author.."|h"..author.."|h");
  finalText = string.gsub(finalText, "#m", text);
   
  local alreadyDisplayed = false;
  
  --Determines whether an identical message has been displayed recently
  for i, v in pairs(ET_VARS["cache"]) do
    if ((text .. author)==v) then
      alreadyDisplayed = true;
    end
  end
 
  --Message has not been displayed recently
  if (alreadyDisplayed~=true) then
    
    --Shifting messages in cache by one index
    for i = 1, #ET_VARS["cache"] - 1, 1 do
      ET_VARS["cache"][i] = ET_VARS["cache"][i+1]        
    end
	 
    --Adding message to end of cache
    ET_VARS["cache"][#ET_VARS["cache"]] = text .. author;
    
    --Printing the message to the user
    local window = getglobal("ChatFrame"..ET_SAVED_VARS["window"]);
    if (window ~= nil) then
      window:AddMessage(finalText, ET_SAVED_VARS["colors"][1]/255, ET_SAVED_VARS["colors"][2]/255, ET_SAVED_VARS["colors"][3]/255);
    else
      DEFAULT_CHAT_FRAME:AddMessage(finalText, ET_SAVED_VARS["colors"][1]/255, ET_SAVED_VARS["colors"][2]/255, ET_SAVED_VARS["colors"][3]/255); 
    end
  end 
end

--Receives a message from another client and processes it
--Arguments:   prefix - string, the prefix of a message sent through addon channels
--                               nil if message was sent through global channel
--             message - string, the raw message sent by another client
--             sender - string, name of the person who sent the message 
--                              not the author, but the person who relayed it
--              addon - boolean, true if message was relayed through addon channel
--                               false if message was relayed through global channel 

local function ProcessRelayedMessage(prefix, message, sender, addon)

  --Message sent through global channel
  if (addon~=true) then

    --prefix and the message are delimited by ";"

    local split = { strsplit(";",message) };
    prefix = split[1];
    
    message = "";
  
    --Reconstructing all other pieces, in the case that trade message contained a ";"
    for i = 2, #split, 1 do 
      message = message .. split[i];
      if (i<#split) then
        message = message .. ";";
      end
    end

   message = string.gsub(message,"*&","|");
  end

  --At this point, any differences in the variables between message relayed through 
  --addon channel and global channel have been eliminated

  --If message was sent in one piece
  if (tonumber(string.sub(prefix,5,5))==1) then
    local authorLength = string.sub(prefix,6) 
    DisplayMessage(string.sub(message,authorLength+1),string.sub(message,1,authorLength));
  else --If message was sent in two pieces
    
    --Unique identifier based on the sender's name and the messageID
    local suid = sender..string.sub(prefix,6,6);
    
    --Creating table to store data temporarily until both pieces have been received
      
    --[1] = # of message received so far
    --[2] = author of message
    --[3] = first part of text
    --[4] = second part of text
    if (ET_VARS["inbox"][suid]==nil) then
      ET_VARS["inbox"][suid] = {};
      ET_VARS["inbox"][suid][1] = 0;
    end
  
    --Adding author and/or text to table
    if (tonumber(string.sub(message,1,1))==1) then
      local authorLength = string.sub(prefix,7);
      ET_VARS["inbox"][suid][2] = string.sub(message,2,authorLength+1);
      ET_VARS["inbox"][suid][3] = string.sub(message,authorLength+2);
    else 
      ET_VARS["inbox"][suid][4] = string.sub(message,2);
    end

    --Incrementing # of messages received
    ET_VARS["inbox"][suid][1] = ET_VARS["inbox"][suid][1] + 1;

    --If all data has been received
    if (ET_VARS["inbox"][suid][1]==2) then
      local text = ET_VARS["inbox"][suid][3]..ET_VARS["inbox"][suid][4];
      DisplayMessage(text, ET_VARS["inbox"][suid][2]);
      ET_VARS["inbox"][suid] = nil;
    end 
  end
end

--Catches all events that addon is registered to
function EverTrade_OnEvent(self, event, ...)

  --Fires when player joins or leaves a guild
  if (event=="PLAYER_GUILD_UPDATE") then
    ET_VARS["inGuild"] = IsInGuild();
    DoRegistrationLogic(ET_VARS["inTrade"], ET_SAVED_VARS["inGlobal"], true);
  end
  
  --Fires when player joins or leaves a channel
  if (event=="CHAT_MSG_CHANNEL_NOTICE") then
   
    local type = select(7, ...);
    --If joined/left trade
    if (type==2) then
      local msg = select(1,...);
      if (msg=="YOU_JOINED") then
        DoRegistrationLogic(true,ET_SAVED_VARS["inGlobal"], false);
      elseif (msg=="YOU_LEFT" or msg=="SUSPENDED") then
        DoRegistrationLogic(false,ET_SAVED_VARS["inGlobal"], false);
      end
    end
     
    local name = select(9, ...);
    --If joined/left global chat
    if (string.lower(name)=="evertrade") then
      local msg = select(1,...);
      if (msg=="YOU_JOINED") then
        DoRegistrationLogic(ET_VARS["inTrade"],true, false);
      elseif (msg=="YOU_LEFT") then
        DoRegistrationLogic(ET_VARS["inTrade"],false, false);       
      end
    end
  end
  
  --Fires when player receives message in a chat channel
  if (event=="CHAT_MSG_CHANNEL") then
    local zoneID = select(7, ...);
    --Message from trade channel
    if (zoneID==2) then
      local message, author = select(1, ...);
      if (ET_VARS["inGuild"]) then
        RelayTradeMessage(author, message, true);
      end
      if (ET_SAVED_VARS["inGlobal"]) then
        RelayTradeMessage(author, message, false);
      end
    end  

    local channelName = select(9, ...)
    --Message from global channel
    if (string.lower(channelName)=="evertrade") then
      local message, author = select(1, ...);
      if (string.find(message,"ET"..ET_VARS["version"])~=nil) then
        if (ET_VARS["inTrade"]==false and ET_SAVED_VARS["show"]) then
          ProcessRelayedMessage(nil, message, author, false);
        end
      end
    end
  end
  
  --Fires when player receives addon message
  if (event=="CHAT_MSG_ADDON") then
    local prefix = select(1, ...);  
    if (string.find(prefix,"ET"..ET_VARS["version"])~=nil) then
      local message = select(2, ...);
      local sender = select(4, ...);
      ProcessRelayedMessage(prefix, message, sender, true);
    end
  end
  
  --Fires after player has joined all his/her regular chat channels
  if (event=="CHANNEL_FLAGS_UPDATED") then
    if (ET_SAVED_VARS["inGlobal"] and IsInGlobal()==false) then
      local confirm = JoinChannelByName("EverTrade");
      if (confirm==nil) then
        ET_SAVED_VARS["inGlobal"] = false;
      end
    end
    --Unregistering itself because it is only needed once upon startup
    this:UnregisterEvent("CHANNEL_FLAGS_UPDATED");
  end
end
              
